@@ -49,16 +49,20 @@ class KeywordProcessor:
         
         return self.data.get(keyword, None)
 
-    def extract(self, text:str, strict:bool=False) -> List[Match]:
-        text = self.normalize(text, self.case_sensitive)
+    def extract(self, text:str, strict:bool=False, normalize:bool=True) -> List[Match]:
+        if normalize:
+            text = self.normalize(text, self.case_sensitive)
+
         return [
             Match(match.start, match.end, match.text, self.data.get(match.text))
             for match in self.node.extract(text, strict)
         ]
 
-    def replace(self, text:str, repl:Dict[str, str]) -> str:
-        text = self.normalize(text, True)
-        matches = self.extract(text)
+    def replace(self, text:str, repl:Dict[str, str], normalize:bool=True) -> str:
+        if normalize:
+            text = self.normalize(text, True)
+        
+        matches = self.extract(text, normalize)
         tokens = []
         curr = 0
 
